pub struct KeyBackupData {
pub first_message_index: u64,
pub forwarded_count: u64,
pub is_verified: bool,
pub session_data: RawJson<EncryptedSessionData>,
}Expand description
Information about the backup key.
To create an instance of this type, first create a [KeyBackupDataInit] and convert it via
KeyBackupData::from / .into().
Fields
first_message_index: u64The index of the first message in the session that the key can decrypt.
forwarded_count: u64The number of times this key has been forwarded via key-sharing between devices.
is_verified: boolWhether the device backing up the key verified the device that the key is from.
session_data: RawJson<EncryptedSessionData>Encrypted data about the session.