#[non_exhaustive]pub enum TokenStringParseError {
Empty,
InvalidCharacter,
}Expand description
The parsed string contains a character not allowed for a TokenString.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
The string is empty.
InvalidCharacter
The string contains an invalid character for a token string.