#[non_exhaustive]pub struct ContentDisposition {
pub disposition_type: ContentDispositionType,
pub filename: Option<String>,
}Expand description
The value of a Content-Disposition HTTP header.
This implementation supports the Content-Disposition header format as defined for HTTP in RFC
6266.
The only supported parameter is filename. It is encoded or decoded as needed, using a quoted
string or the ext-token = ext-value format, with the encoding defined in RFC 8187.
This implementation does not support serializing to the format defined for the
multipart/form-data content type in RFC 7578. It should however manage to parse the
disposition type and filename parameter of the body parts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.disposition_type: ContentDispositionTypeThe disposition type.
filename: Option<String>The filename of the content.
Implementations
Sourceimpl ContentDisposition
impl ContentDisposition
Sourcepub fn new(disposition_type: ContentDispositionType) -> Self
pub fn new(disposition_type: ContentDispositionType) -> Self
Creates a new ContentDisposition with the given disposition type.
Sourcepub fn with_filename(self, filename: Option<String>) -> Self
pub fn with_filename(self, filename: Option<String>) -> Self
Add the given filename to this ContentDisposition.