OwnedServerSigningKeyVersion

Struct OwnedServerSigningKeyVersion 

pub struct OwnedServerSigningKeyVersion { /* private fields */ }
Owned variant of ServerSigningKeyVersion

The wrapper type for this type is variable, by default it’ll use Box, but you can change that by setting “--cfg=palpo_identifiers_storage=...” using RUSTFLAGS or .cargo/config.toml (under [build] -> rustflags = ["..."]) to the following;

  • palpo_identifiers_storage="Arc" to use Arc as a wrapper type.

Methods from Deref<Target = ServerSigningKeyVersion>

pub fn as_str(&self) -> &str

Creates a string slice from this ServerSigningKeyVersion.

pub fn as_bytes(&self) -> &[u8]

Creates a byte slice from this ServerSigningKeyVersion.