ServerSigningKeyVersion

Struct ServerSigningKeyVersion 

pub struct ServerSigningKeyVersion(/* private fields */);
The version of a homeserver signing key.

This is an opaque character sequences of [a-zA-Z0-9_]. This type is provided simply for its semantic value.

With the compat-server-signing-key-version cargo feature, the validation of this type is relaxed to accept any string.

Implementations

Source

impl ServerSigningKeyVersion

pub fn as_str(&self) -> &str

Creates a string slice from this ServerSigningKeyVersion.

pub fn as_bytes(&self) -> &[u8]

Creates a byte slice from this ServerSigningKeyVersion.

Source

impl ServerSigningKeyVersion

pub fn parse( s: impl AsRef<str>, ) -> Result<OwnedServerSigningKeyVersion, IdParseError>

Try parsing a &str into an OwnedServerSigningKeyVersion.

The same can also be done using FromStr, TryFrom or TryInto. This function is simply more constrained and thus useful in generic contexts.

pub fn parse_box( s: impl AsRef<str> + Into<Box<str>>, ) -> Result<Box<Self>, IdParseError>

Try parsing a &str into a Box<ServerSigningKeyVersion>.

The same can also be done using FromStr, TryFrom or TryInto. This function is simply more constrained and thus useful in generic contexts.

pub fn parse_rc( s: impl AsRef<str> + Into<Rc<str>>, ) -> Result<Rc<Self>, IdParseError>

Try parsing a &str into an Rc<ServerSigningKeyVersion>.

pub fn parse_arc( s: impl AsRef<str> + Into<Arc<str>>, ) -> Result<Arc<Self>, IdParseError>

Try parsing a &str into an Arc<ServerSigningKeyVersion>.