pub enum AnyPushRule {
Override(ConditionalPushRule),
Content(PatternedPushRule),
Room(SimplePushRule<OwnedRoomId>),
Sender(SimplePushRule<OwnedUserId>),
Underride(ConditionalPushRule),
}Expand description
The kinds of push rules that are available.
Variants
Override(ConditionalPushRule)
Rules that override all other kinds.
Content(PatternedPushRule)
Content-specific rules.
Room(SimplePushRule<OwnedRoomId>)
Room-specific rules.
Sender(SimplePushRule<OwnedUserId>)
Sender-specific rules.
Underride(ConditionalPushRule)
Lowest priority rules.
Implementations
Sourceimpl AnyPushRule
impl AnyPushRule
Sourcepub fn as_ref(&self) -> AnyPushRuleRef<'_>
pub fn as_ref(&self) -> AnyPushRuleRef<'_>
Convert AnyPushRule to AnyPushRuleRef.
Sourcepub fn triggers_highlight(&self) -> bool
pub fn triggers_highlight(&self) -> bool
Whether an event that matches the push rule should be highlighted.
Sourcepub fn triggers_notification(&self) -> bool
pub fn triggers_notification(&self) -> bool
Whether an event that matches the push rule should trigger a notification.
Sourcepub fn triggers_sound(&self) -> Option<&str>
pub fn triggers_sound(&self) -> Option<&str>
The sound that should be played when an event matches the push rule, if any.
Sourcepub fn is_server_default(&self) -> bool
pub fn is_server_default(&self) -> bool
Whether the push rule is a server-default rule.
Sourcepub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx,
) -> bool
pub fn applies( &self, event: &FlattenedJson, context: &PushConditionRoomCtx, ) -> bool
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.