pub enum AnyPushRuleRef<'a> {
Override(&'a ConditionalPushRule),
Content(&'a PatternedPushRule),
Room(&'a SimplePushRule<OwnedRoomId>),
Sender(&'a SimplePushRule<OwnedUserId>),
Underride(&'a ConditionalPushRule),
}Expand description
Reference to any kind of push rule.
Variants
Override(&'a ConditionalPushRule)
Rules that override all other kinds.
Content(&'a PatternedPushRule)
Content-specific rules.
Room(&'a SimplePushRule<OwnedRoomId>)
Room-specific rules.
Sender(&'a SimplePushRule<OwnedUserId>)
Sender-specific rules.
Underride(&'a ConditionalPushRule)
Lowest priority rules.
Implementations
Sourceimpl<'a> AnyPushRuleRef<'a>
impl<'a> AnyPushRuleRef<'a>
Sourcepub fn to_owned(self) -> AnyPushRule
pub fn to_owned(self) -> AnyPushRule
Convert AnyPushRuleRef to AnyPushRule by cloning the inner value.
Sourcepub fn triggers_highlight(self) -> bool
pub fn triggers_highlight(self) -> bool
Whether an event that matches the push rule should be highlighted.
Sourcepub fn triggers_notification(self) -> bool
pub fn triggers_notification(self) -> bool
Whether an event that matches the push rule should trigger a notification.
Sourcepub fn triggers_sound(self) -> Option<&'a str>
pub fn triggers_sound(self) -> Option<&'a str>
The sound that should be played when an event matches the push rule, if any.
Sourcepub fn is_server_default(self) -> bool
pub fn is_server_default(self) -> bool
Whether the push rule is a server-default rule.
Sourcepub fn applies(
self,
event: &FlattenedJson,
context: &PushConditionRoomCtx,
) -> bool
pub fn applies( self, event: &FlattenedJson, context: &PushConditionRoomCtx, ) -> bool
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.