pub struct PatternedPushRuleInit {
pub actions: Vec<Action>,
pub default: bool,
pub enabled: bool,
pub rule_id: String,
pub pattern: String,
}Expand description
Initial set of fields of PatterenedPushRule.
This struct will not be updated even if additional fields are added to PatterenedPushRule in a
new (non-breaking) release of the Matrix specification.
Fields
actions: Vec<Action>Actions to determine if and how a notification is delivered for events matching this rule.
default: boolWhether this is a default rule, or has been set explicitly.
enabled: boolWhether the push rule is enabled or not.
rule_id: StringThe ID of this rule.
pattern: StringThe glob-style pattern to match against.