pub struct PushConditionPowerLevelsCtx {
pub users: BTreeMap<OwnedUserId, i64>,
pub users_default: i64,
pub notifications: NotificationPowerLevels,
}Expand description
The room power levels context to be able to test the corresponding push conditions.
Fields
users: BTreeMap<OwnedUserId, i64>The power levels of the users of the room.
users_default: i64The default power level of the users of the room.
notifications: NotificationPowerLevelsThe notification power levels of the room.