pub struct PushConditionRoomCtx {
pub room_id: OwnedRoomId,
pub member_count: u64,
pub user_id: OwnedUserId,
pub user_display_name: String,
pub power_levels: Option<PushConditionPowerLevelsCtx>,
pub supported_features: Vec<RoomVersionFeature>,
}Expand description
The context of the room associated to an event to be able to test all push conditions.
Fields
room_id: OwnedRoomIdThe ID of the room.
member_count: u64The number of members in the room.
user_id: OwnedUserIdThe user’s matrix ID.
user_display_name: StringThe display name of the current user in the room.
power_levels: Option<PushConditionPowerLevelsCtx>The room power levels context for the room.
If this is missing, push rules that require this will never match.
supported_features: Vec<RoomVersionFeature>The list of features this room’s version or the room itself supports.